@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -86,7 +86,6 @@ class DrawingComponents(Collection):
         :param DrawingView i_drawing_component_ref:
         :param float i_position_x:
         :param float i_position_y:
-        :return: DrawingComponent
         :rtype: DrawingComponent
         """
         return DrawingComponent(
@@ -136,7 +135,6 @@ class DrawingComponents(Collection):
                 |      Set ThisDrawingComponent = MyView.Components.Item(2)
 
         :param cat_variant i_index:
-        :return: DrawingComponent
         :rtype: DrawingComponent
         """
         return DrawingComponent(self.drawing_components.Item(i_index))
@@ -174,7 +172,6 @@ class DrawingComponents(Collection):
                 |      MyView.Components.Remove(3)
 
         :param cat_variant i_index:
-        :return: None
         :rtype: None
         """
         return self.drawing_components.Remove(i_index)
@@ -183,11 +180,11 @@ class DrawingComponents(Collection):
         if (n + 1) > self.count:
             raise StopIteration
 
-        return DrawingComponent(self.drawing_components.item(n + 1))
+        return DrawingComponent(self.drawing_components.Item(n + 1))
 
     def __iter__(self) -> Iterator[DrawingComponent]:
         for i in range(self.count):
-            yield self.child_object(self.com_object.item(i + 1))
+            yield self.child_object(self.com_object.Item(i + 1))
 
     def __repr__(self):
         return f'DrawingComponents()'
