@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -58,7 +58,6 @@ class DrawingDimension(AnyObject):
                 | 
                 |          oCumulateMode = MyDimension.CumulateMode
 
-        :return: bool
         :rtype: bool
         """
 
@@ -81,7 +80,7 @@ class DrawingDimension(AnyObject):
                 | 
                 |          oIsStatus = MyDimension.DimStatus
 
-        :return: int
+        :return: enum cat_dim_analyse
         :rtype: int
         """
 
@@ -104,7 +103,7 @@ class DrawingDimension(AnyObject):
                 | 
                 |          oTypeDim = MyDimension.DimType
 
-        :return: int
+        :return: enum cat_dim_type
         :rtype: int
         """
 
@@ -127,7 +126,7 @@ class DrawingDimension(AnyObject):
                 | 
                 |          oDualValue = MyDimension.DualValue
 
-        :return: int
+        :return: enum cat_dim_dual_display
         :rtype: int
         """
 
@@ -136,7 +135,7 @@ class DrawingDimension(AnyObject):
     @dual_value.setter
     def dual_value(self, value: int):
         """
-        :param int value:
+        :param int value: enum cat_dim_dual_display
         """
 
         self.drawing_dimension.DualValue = value
@@ -158,7 +157,6 @@ class DrawingDimension(AnyObject):
                 | 
                 |          oForsh = MyDimension.Forshortened
 
-        :return: bool
         :rtype: bool
         """
 
@@ -189,7 +187,6 @@ class DrawingDimension(AnyObject):
                 | 
                 |          oHalfDimMode = MyDimension.HalfDimMode
 
-        :return: bool
         :rtype: bool
         """
 
@@ -219,7 +216,6 @@ class DrawingDimension(AnyObject):
                 | 
                 |      myDimensionClippingStatus=MyDimension.IsClipped
 
-        :return: bool
         :rtype: bool
         """
 
@@ -242,7 +238,6 @@ class DrawingDimension(AnyObject):
                 | 
                 |          oNbExtline = MyDimension.NbExtLine
 
-        :return: int
         :rtype: int
         """
 
@@ -265,7 +260,6 @@ class DrawingDimension(AnyObject):
                 | 
                 |          oNbSymb = MyDimension.NbSymb
 
-        :return: int
         :rtype: int
         """
 
@@ -297,7 +291,6 @@ class DrawingDimension(AnyObject):
                 |          Dim DimValueParameter As Parameter
                 |          Set DimValueParameter = DimensionParameters.Item("Measured length")
 
-        :return: Parameters
         :rtype: Parameters
         """
 
@@ -322,7 +315,6 @@ class DrawingDimension(AnyObject):
                 | 
                 |          oSymbSide = MyDimension.SymbolsSide
 
-        :return: int
         :rtype: int
         """
 
@@ -375,7 +367,6 @@ class DrawingDimension(AnyObject):
                 | 
                 |          oValueAng = MyDimension.ValueAngle
 
-        :return: float
         :rtype: float
         """
 
@@ -406,7 +397,6 @@ class DrawingDimension(AnyObject):
                 | 
                 |          oValueAutoMode = MyDimension.ValueAutoMode
 
-        :return: int
         :rtype: int
         """
 
@@ -437,7 +427,6 @@ class DrawingDimension(AnyObject):
                 | 
                 |          oValueDisplay = MyDimension.ValueDisplay
 
-        :return: int
         :rtype: int
         """
 
@@ -468,7 +457,7 @@ class DrawingDimension(AnyObject):
                 | 
                 |          oValueFrame = MyDimension.ValueFrame
 
-        :return: int
+        :return: enum cat_dim_frame
         :rtype: int
         """
 
@@ -477,7 +466,7 @@ class DrawingDimension(AnyObject):
     @value_frame.setter
     def value_frame(self, value: int):
         """
-        :param int value:
+        :param int value: enum cat_dim_frame
         """
 
         self.drawing_dimension.ValueFrame = value
@@ -499,7 +488,6 @@ class DrawingDimension(AnyObject):
                 | 
                 |          oInOut = MyDimension.ValueInOut
 
-        :return: int
         :rtype: int
         """
 
@@ -530,7 +518,7 @@ class DrawingDimension(AnyObject):
                 | 
                 |          oValueOrient = MyDimension.ValueOrientation
 
-        :return: int
+        :return: enum cat_dim_orientation
         :rtype: int
         """
 
@@ -539,7 +527,7 @@ class DrawingDimension(AnyObject):
     @value_orientation.setter
     def value_orientation(self, value: int):
         """
-        :param int value:
+        :param int value: enum cat_dim_orientation
         """
 
         self.drawing_dimension.ValueOrientation = value
@@ -561,7 +549,7 @@ class DrawingDimension(AnyObject):
                 | 
                 |          oValueRef = MyDimension.ValueReference
 
-        :return: int
+        :return: enum cat_dim_reference
         :rtype: int
         """
 
@@ -570,7 +558,7 @@ class DrawingDimension(AnyObject):
     @value_reference.setter
     def value_reference(self, value: int):
         """
-        :param int value:
+        :param int value: enum cat_dim_reference
         """
 
         self.drawing_dimension.ValueReference = value
@@ -596,7 +584,6 @@ class DrawingDimension(AnyObject):
                 | 
                 |              MyDimension.GetBoundaryBox(oValues)
 
-        :return: tuple
         :rtype: tuple
         """
         return self.drawing_dimension.GetBoundaryBox()
@@ -674,7 +661,6 @@ class DrawingDimension(AnyObject):
                 |     See also:
                 |         DrawingDimLine
 
-        :return: DrawingDimExtLine
         :rtype: DrawingDimExtLine
         """
         return DrawingDimExtLine(self.drawing_dimension.GetDimExtLine())
@@ -701,7 +687,6 @@ class DrawingDimension(AnyObject):
                 |     See also:
                 |         DrawingDimLine
 
-        :return: DrawingDimLine
         :rtype: DrawingDimLine
         """
         return DrawingDimLine(self.drawing_dimension.GetDimLine())
@@ -771,7 +756,6 @@ class DrawingDimension(AnyObject):
                 |     See also:
                 |         DrawingDimValue
 
-        :return: DrawingDimValue
         :rtype: DrawingDimValue
         """
         return DrawingDimValue(self.drawing_dimension.GetValue())
@@ -822,7 +806,6 @@ class DrawingDimension(AnyObject):
         :param float y:
         :param int sub_part:
         :param int dim_angle_behavior:
-        :return: None
         :rtype: None
         """
         return self.drawing_dimension.MoveValue(x, y, sub_part, dim_angle_behavior)
@@ -842,7 +825,6 @@ class DrawingDimension(AnyObject):
                 | 
                 |      MyDimension.RestoreValuePosition()
 
-        :return: None
         :rtype: None
         """
         return self.drawing_dimension.RestoreValuePosition()
@@ -880,7 +862,6 @@ class DrawingDimension(AnyObject):
         :param float x:
         :param float y:
         :param int i_kept_side:
-        :return: None
         :rtype: None
         """
         return self.drawing_dimension.SetClip(x, y, i_kept_side)
@@ -938,7 +919,6 @@ class DrawingDimension(AnyObject):
         :param float id_up_tol:
         :param float id_low_tol:
         :param int display_mode:
-        :return: None
         :rtype: None
         """
         return self.drawing_dimension.SetTolerances(
@@ -966,7 +946,6 @@ class DrawingDimension(AnyObject):
                 |      if MyDimension.IsClipped then
                 |        MyDimension.Unclip
 
-        :return: None
         :rtype: None
         """
         return self.drawing_dimension.Unclip()
