@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -103,11 +103,10 @@ class DrawingDimensions(Collection):
                 |      Dim MyDimension2 As DrawingDimension
                 |      Set MyDimension2 = MyView.Dimensions.Add(iType, myElements2(1), selpoints(3),catDimOffset)
 
-        :param int i_type_dim:
+        :param int i_type_dim: enum cat_dim_type
         :param tuple i_geom_elem:
         :param tuple i_pt_coord_elem:
         :param int i_line_rep:
-        :return: DrawingDimension
         :rtype: DrawingDimension
         """
         return DrawingDimension(
@@ -186,12 +185,11 @@ class DrawingDimensions(Collection):
                 |      Dim MyDimension As DrawingDimension
                 |      Set MyDimension = MyView.Dimensions.Add2(iType, myElements(1), selpoints(3), Line1, 0)
 
-        :param int i_type_dim:
+        :param int i_type_dim: enum cat_dim_type
         :param tuple i_geom_elem:
         :param tuple i_pt_coord_elem:
-        :param CATVariant i_ldc_ref_elem:
+        :param cat_variant i_ldc_ref_elem:
         :param int i_ldc_ref_angle:
-        :return: DrawingDimension
         :rtype: DrawingDimension
         """
         return DrawingDimension(
@@ -246,7 +244,6 @@ class DrawingDimensions(Collection):
                 |          Set ThatDrawingDimension = MyView.Dimensions.Item("MyDimension")
 
         :param cat_variant i_index:
-        :return: DrawingDimension
         :rtype: DrawingDimension
         """
         return DrawingDimension(self.drawing_dimensions.Item(i_index))
@@ -281,7 +278,6 @@ class DrawingDimensions(Collection):
                 |          MyView.Dimensions.Remove(3)
 
         :param cat_variant i_index:
-        :return: None
         :rtype: None
         """
         return self.drawing_dimensions.Remove(i_index)
@@ -290,11 +286,11 @@ class DrawingDimensions(Collection):
         if (n + 1) > self.count:
             raise StopIteration
 
-        return DrawingDimension(self.drawing_dimensions.item(n + 1))
+        return DrawingDimension(self.drawing_dimensions.Item(n + 1))
 
     def __iter__(self) -> Iterator[DrawingDimension]:
         for i in range(self.count):
-            yield self.child_object(self.com_object.item(i + 1))
+            yield self.child_object(self.com_object.Item(i + 1))
 
     def __repr__(self):
         return f'DrawingDimensions(name="{self.name}")'
