@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -57,7 +57,6 @@ class DrawingRoot(DrawingDocument):
                 | 
                 |          CATIA.ActiveDocument.DrawingRoot.GetActiveSheet
 
-        :return: DrawingSheet
         :rtype: DrawingSheet
         """
 
@@ -97,7 +96,6 @@ class DrawingRoot(DrawingDocument):
                 |          drwsheetsorder.reorder_Sheets(newsheetorder)
 
         :param tuple i_ordered_sheets:
-        :return: None
         :rtype: None
         """
         sheets = [x.com_object for x in i_ordered_sheets]
