@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -89,7 +89,6 @@ class DrawingTables(Collection):
         :param int i_number_of_column:
         :param float i_row_height:
         :param float i_column_width:
-        :return: DrawingTable
         :rtype: DrawingTable
         """
         return DrawingTable(
@@ -135,7 +134,6 @@ class DrawingTables(Collection):
                 |          Set ThisDrawingTable = MyView.Tables.Item(2)
 
         :param int i_index:
-        :return: DrawingTable
         :rtype: DrawingTable
         """
         return DrawingTable(self.drawing_tables.Item(i_index))
@@ -176,11 +174,11 @@ class DrawingTables(Collection):
         if (n + 1) > self.count:
             raise StopIteration
 
-        return DrawingTable(self.drawing_tables.item(n + 1))
+        return DrawingTable(self.drawing_tables.Item(n + 1))
 
     def __iter__(self) -> Iterator[DrawingTable]:
         for i in range(self.count):
-            yield self.child_object(self.com_object.item(i + 1))
+            yield self.child_object(self.com_object.Item(i + 1))
 
     def __repr__(self):
         return f'DrawingTables(name="{self.name}")'
