@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -69,7 +69,6 @@ class DrawingThreads(Collection):
                 |      Set MyThread = MyView.Threads.Add(iGeomElem)
 
         :param i_geom_elem:
-        :return: DrawingThread
         :rtype: DrawingThread
         """
         return DrawingThread(self.drawing_threads.Add(i_geom_elem.com_object))
@@ -107,7 +106,6 @@ class DrawingThreads(Collection):
                 |          Set ThisDrawingThread = MyView.Threads.Item(2)
 
         :param int i_index:
-        :return: DrawingThread
         :rtype: DrawingThread
         """
         return DrawingThread(self.drawing_threads.Item(i_index))
@@ -142,7 +140,6 @@ class DrawingThreads(Collection):
                 |          MyView.DrawingThreads.Remove(3)
 
         :param int i_index:
-        :return: None
         :rtype: None
         """
         return self.drawing_threads.Remove(i_index)
@@ -151,11 +148,11 @@ class DrawingThreads(Collection):
         if (n + 1) > self.count:
             raise StopIteration
 
-        return DrawingThread(self.drawing_threads.item(n + 1))
+        return DrawingThread(self.drawing_threads.Item(n + 1))
 
     def __iter__(self) -> Iterator[DrawingThread]:
         for i in range(self.count):
-            yield self.child_object(self.com_object.item(i + 1))
+            yield self.child_object(self.com_object.Item(i + 1))
 
     def __repr__(self):
         return f'DrawingThreads(name="{self.name}")'
