@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -65,7 +65,6 @@ class DrawingViews(Collection):
                 |          Dim ViewToWorkIn As DrawingView
                 |          Set ViewToWorkIn = MyDrawingDoc.Sheets.ActiveSheet.DrawingViews.ActiveView
 
-        :return: DrawingView
         :rtype: DrawingView
         """
 
@@ -106,7 +105,6 @@ class DrawingViews(Collection):
                 |      Set MyView = MySheet.Views.Add("LeftView")
 
         :param str i_drawing_view_name:
-        :return: DrawingView
         :rtype: DrawingView
         """
         return DrawingView(self.drawing_views.Add(i_drawing_view_name))
@@ -157,7 +155,6 @@ class DrawingViews(Collection):
                 |          Set ThatDrawingView = MySheet.Views.ActiveView.Item("MyView")
 
         :param cat_variant i_index:
-        :return: DrawingView
         :rtype: DrawingView
         """
         return DrawingView(self.drawing_views.Item(i_index))
@@ -199,7 +196,6 @@ class DrawingViews(Collection):
                 |      MySheet.ActiveViews.Remove("TopView")
 
         :param cat_variant i_index:
-        :return: None
         :rtype: None
         """
         return self.drawing_views.Remove(i_index)
@@ -208,11 +204,11 @@ class DrawingViews(Collection):
         if (n + 1) > self.count:
             raise StopIteration
 
-        return DrawingView(self.drawing_views.item(n + 1))
+        return DrawingView(self.drawing_views.Item(n + 1))
 
     def __iter__(self) -> Iterator[DrawingView]:
         for i in range(self.count):
-            yield self.child_object(self.com_object.item(i + 1))
+            yield self.child_object(self.com_object.Item(i + 1))
 
     def __repr__(self):
         return f'DrawingViews(name="{self.name}")'
