@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384
 
@@ -61,7 +61,6 @@ class HybridShapeInverse(HybridShape):
                 |     See also:
                 |         HybridShapeFactory
 
-        :return: Reference
         :rtype: Reference
         """
 
@@ -88,7 +87,6 @@ class HybridShapeInverse(HybridShape):
                 |     Orientation = 1 : the element is not inverted. = -1 : the element is inverted, =
                 |      2 : the element can not be inverted. Orientation can not be set to 2.
 
-        :return: int
         :rtype: int
         """
 
