@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384
 
@@ -9,9 +9,12 @@
         
 """
 
+from typing import Union
+
 from pycatia.in_interfaces.reference import Reference
 from pycatia.knowledge_interfaces.length import Length
 from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape
+from pycatia.scripts.vba import VBANothing, vba_nothing
 
 
 class HybridShapeLoft(HybridShape):
@@ -70,7 +73,6 @@ class HybridShapeLoft(HybridShape):
                 |     Gets or sets the optional area law for multi-sections element definition.
                 |     The law is a length law.
 
-        :return: Reference
         :rtype: Reference
         """
 
@@ -95,7 +97,6 @@ class HybridShapeLoft(HybridShape):
                 | 
                 |     Gets or sets the tolerance applied to area law. The value is in mm.
 
-        :return: float
         :rtype: float
         """
 
@@ -126,7 +127,6 @@ class HybridShapeLoft(HybridShape):
                 |      Dim BoolOp
                 |      BoolOp = Loft.BooleanOperation
 
-        :return: int
         :rtype: int
         """
 
@@ -160,7 +160,6 @@ class HybridShapeLoft(HybridShape):
                 |     2
                 |         Detection of canonical surfaces is performed
 
-        :return: int
         :rtype: int
         """
 
@@ -192,7 +191,6 @@ class HybridShapeLoft(HybridShape):
                 |     2
                 |         The tangent to the end section is not computed
 
-        :return: int
         :rtype: int
         """
 
@@ -224,7 +222,6 @@ class HybridShapeLoft(HybridShape):
                 |     2
                 |         The tangent to the start section is not computed
 
-        :return: int
         :rtype: int
         """
 
@@ -263,7 +260,6 @@ class HybridShapeLoft(HybridShape):
                 |          Dim oContext
                 |          Set oContext = Loft.Context
 
-        :return: int
         :rtype: int
         """
 
@@ -329,7 +325,6 @@ class HybridShapeLoft(HybridShape):
                 |                 By the guides extremities opposite to the last section, if
                 |                 there are guides
 
-        :return: int
         :rtype: int
         """
 
@@ -372,7 +367,6 @@ class HybridShapeLoft(HybridShape):
                 |         if each curve has the same number of vertices, then these points will
                 |         be coupled, otherwise an error message is displayed
 
-        :return: int
         :rtype: int
         """
 
@@ -398,7 +392,6 @@ class HybridShapeLoft(HybridShape):
                 |     Returns or sets the angular threshold under which discontinuities (moving
                 |     frame, tangency net on reference surface) will be smoothed.
 
-        :return: float
         :rtype: float
         """
 
@@ -432,7 +425,6 @@ class HybridShapeLoft(HybridShape):
                 |         The angular threshold value is not used during the lofting
                 |         operation
 
-        :return: bool
         :rtype: bool
         """
 
@@ -458,7 +450,6 @@ class HybridShapeLoft(HybridShape):
                 |     Returns or sets the deviation value (length) allowed during lofting
                 |     operation in order to smooth it.
 
-        :return: float
         :rtype: float
         """
 
@@ -492,7 +483,6 @@ class HybridShapeLoft(HybridShape):
                 |         The deviation value is not used during the lofting
                 |         operation
 
-        :return: bool
         :rtype: bool
         """
 
@@ -526,7 +516,6 @@ class HybridShapeLoft(HybridShape):
                 |         Boundary object): TriDimFeatEdge and BiDimFeatEdge.
 
         :param Reference i_guide:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.AddGuide(i_guide.com_object)
@@ -574,7 +563,6 @@ class HybridShapeLoft(HybridShape):
 
         :param Reference i_guide:
         :param Reference i_tangent:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.AddGuideWithTangent(i_guide.com_object, i_tangent.com_object)
@@ -594,7 +582,12 @@ class HybridShapeLoft(HybridShape):
         # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def add_section_to_loft(self, i_crv: Reference, i_ori: int, i_point: Reference) -> None:
+    def add_section_to_loft(
+            self,
+            i_crv: Reference,
+            i_ori: int,
+            i_point: Union[Reference, VBANothing]
+    ) -> None:
         """
         .. note::
             :class: toggle
@@ -617,11 +610,16 @@ class HybridShapeLoft(HybridShape):
 
         :param Reference i_crv:
         :param int i_ori:
-        :param Reference i_point:
-        :return: None
+        :param Reference or VBANothing i_point:
         :rtype: None
         """
-        return self.hybrid_shape_loft.AddSectionToLoft(i_crv.com_object, i_ori, i_point.com_object)
+
+        if i_point:
+            i_point = self.application.system_service.evaluate(vba_nothing, 0, 'N', [])
+        else:
+            i_point = i_point.com_object
+
+        return self.hybrid_shape_loft.AddSectionToLoft(i_crv.com_object, i_ori, i_point)
         # # # # Autogenerated comment: 
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
@@ -648,7 +646,6 @@ class HybridShapeLoft(HybridShape):
                 | 
                 |     Gets the tolerance parameter applied to area law.
 
-        :return: Length
         :rtype: Length
         """
         return Length(self.hybrid_shape_loft.GetAreaLawToleranceParameter())
@@ -675,7 +672,6 @@ class HybridShapeLoft(HybridShape):
 
         :param Reference o_start_face:
         :param Reference o_end_face:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.GetFacesForClosing(o_start_face.com_object, o_end_face.com_object)
@@ -721,7 +717,6 @@ class HybridShapeLoft(HybridShape):
         :param int i_pos:
         :param Reference o_guide:
         :param Reference o_guide_tangent:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.GetGuide(i_pos, o_guide.com_object, o_guide_tangent.com_object)
@@ -763,7 +758,6 @@ class HybridShapeLoft(HybridShape):
                 |                  Dim oSize As  long
                 |                  oSize = hybShpLoft.GetNbOfGuides
 
-        :return: int
         :rtype: int
         """
         return self.hybrid_shape_loft.GetNbOfGuides()
@@ -796,7 +790,6 @@ class HybridShapeLoft(HybridShape):
         :param Reference o_crv:
         :param int o_ori:
         :param Reference o_point:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.GetSectionFromLoft(i_rank, o_crv.com_object, o_ori, o_point.com_object)
@@ -837,7 +830,6 @@ class HybridShapeLoft(HybridShape):
 
         :param int o_spine_type:
         :param Reference o_spine:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.GetSpine(o_spine_type, o_spine.com_object)
@@ -880,7 +872,6 @@ class HybridShapeLoft(HybridShape):
 
         :param Reference o_start_section_tangent:
         :param Reference o_end_section_tangent:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.GetStartAndEndSectionTangent(o_start_section_tangent.com_object,
@@ -922,7 +913,6 @@ class HybridShapeLoft(HybridShape):
                 |         Boundary object): Vertex.
 
         :param int i_position:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.InsertCoupling(i_position)
@@ -959,7 +949,6 @@ class HybridShapeLoft(HybridShape):
         :param int i_coupling_index:
         :param int i_position:
         :param Reference i_point:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.InsertCouplingPoint(i_coupling_index, i_position, i_point.com_object)
@@ -1014,7 +1003,6 @@ class HybridShapeLoft(HybridShape):
         :param int i_ori:
         :param Reference i_point:
         :param Reference i_section_ref:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.InsertSectionToLoft(i_type, i_crv.com_object, i_ori, i_point.com_object,
@@ -1055,7 +1043,6 @@ class HybridShapeLoft(HybridShape):
 
         :param Reference i_guide:
         :param Reference i_new_guide:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.ModifyGuideCurve(i_guide.com_object, i_new_guide.com_object)
@@ -1117,7 +1104,6 @@ class HybridShapeLoft(HybridShape):
         :param Reference o_curve_section:
         :param Reference o_closing_point:
         :param int o_pt_diag:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.ModifySectionCurve(i_section.com_object, i_new_section.com_object,
@@ -1163,7 +1149,6 @@ class HybridShapeLoft(HybridShape):
 
         :param Reference i_section:
         :param int i_orient:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.ModifySectionOrient(i_section.com_object, i_orient)
@@ -1199,7 +1184,6 @@ class HybridShapeLoft(HybridShape):
                 |             section curve.
 
         :param Reference i_section:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.RemoveFaceForClosing(i_section.com_object)
@@ -1239,7 +1223,6 @@ class HybridShapeLoft(HybridShape):
                 |         Boundary object): TriDimFeatEdge and BiDimFeatEdge.
 
         :param Reference i_guide:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.RemoveGuide(i_guide.com_object)
@@ -1277,7 +1260,6 @@ class HybridShapeLoft(HybridShape):
                 |             removed.
 
         :param Reference i_guide:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.RemoveGuideTangent(i_guide.com_object)
@@ -1317,7 +1299,6 @@ class HybridShapeLoft(HybridShape):
                 |         Boundary object): TriDimFeatEdge and BiDimFeatEdge.
 
         :param Reference i_section:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.RemoveSection(i_section.com_object)
@@ -1355,7 +1336,6 @@ class HybridShapeLoft(HybridShape):
                 |             removed.
 
         :param Reference i_section:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.RemoveSectionPoint(i_section.com_object)
@@ -1394,7 +1374,6 @@ class HybridShapeLoft(HybridShape):
                 |             removed.
 
         :param Reference i_section:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.RemoveSectionTangent(i_section.com_object)
@@ -1433,7 +1412,6 @@ class HybridShapeLoft(HybridShape):
                 |         Boundary object): Face.
 
         :param Reference i_face:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.SetEndFaceForClosing(i_face.com_object)
@@ -1474,7 +1452,6 @@ class HybridShapeLoft(HybridShape):
                 |         Boundary object): Face.
 
         :param Reference i_tangent_section:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.SetEndSectionTangent(i_tangent_section.com_object)
@@ -1513,7 +1490,6 @@ class HybridShapeLoft(HybridShape):
                 |         Boundary object): TriDimFeatEdge and BiDimFeatEdge.
 
         :param Reference i_spine:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.SetSpine(i_spine.com_object)
@@ -1552,7 +1528,6 @@ class HybridShapeLoft(HybridShape):
                 |         Boundary object): Face.
 
         :param Reference i_face:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.SetStartFaceForClosing(i_face.com_object)
@@ -1593,7 +1568,6 @@ class HybridShapeLoft(HybridShape):
                 |         Boundary object): Face.
 
         :param Reference i_tangent_section:
-        :return: None
         :rtype: None
         """
         return self.hybrid_shape_loft.SetStartSectionTangent(i_tangent_section.com_object)
