@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384
 
@@ -62,7 +62,6 @@ class HybridShapeMidSurface(HybridShape):
                 |     Returns or sets AutoThicknessThreshold. Automatic Thickmess Threshold Check Button ON :1,
                 |     OFF : 0 (Only Automatic Creation Mode Available for Automation)
 
-        :return: int
         :rtype: int
         """
 
@@ -88,7 +87,6 @@ class HybridShapeMidSurface(HybridShape):
                 |     Returns or sets CreationMode. Face Pairs : 0, Faces To Offset : 1, Automatic :
                 |     2 (Only Automatic Creation Mode Available for Automation)
 
-        :return: int
         :rtype: int
         """
 
@@ -113,7 +111,6 @@ class HybridShapeMidSurface(HybridShape):
                 | 
                 |     Returns or sets Support Body. Reference.
 
-        :return: Reference
         :rtype: Reference
         """
 
@@ -138,7 +135,6 @@ class HybridShapeMidSurface(HybridShape):
                 | 
                 |     Returns or sets Threshold Thickness. Length.
 
-        :return: Length
         :rtype: Length
         """
 
