@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384
 
@@ -63,7 +63,6 @@ class HybridShapePlane2Lines(Plane):
                 |     See also:
                 |         HybridShapeFactory
 
-        :return: Reference
         :rtype: Reference
         """
 
@@ -89,7 +88,6 @@ class HybridShapePlane2Lines(Plane):
                 |     if ForbidNonCoplanarLines = TRUE, both lines have to be on the same plane.
                 |     if ForbidNonCoplanarLines = FALSE, both lines can be non coplanar.
 
-        :return: bool
         :rtype: bool
         """
 
@@ -127,7 +125,6 @@ class HybridShapePlane2Lines(Plane):
                 |     See also:
                 |         HybridShapeFactory
 
-        :return: Reference
         :rtype: Reference
         """
 
