@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384
 
@@ -66,7 +66,6 @@ class HybridShapePointBetween(Point):
                 |          Dim RefPoint1 As Reference
                 |          Set RefPoint1 = PointBetween.FirstPoint
 
-        :return: Reference
         :rtype: Reference
         """
 
@@ -99,7 +98,6 @@ class HybridShapePointBetween(Point):
                 |          Dim Orient As long
                 |          Set Orient = PointBetween.Orientation
 
-        :return: int
         :rtype: int
         """
 
@@ -133,7 +131,6 @@ class HybridShapePointBetween(Point):
                 |          Dim ratio  As CATIARealParam
                 |          Get ratio = PointBetween.Ratio
 
-        :return: RealParam
         :rtype: RealParam
         """
 
@@ -158,7 +155,6 @@ class HybridShapePointBetween(Point):
                 |          Dim RefPoint2 As Reference
                 |          Set RefPoint2 = PointBetween.SecondPoint
 
-        :return: Reference
         :rtype: Reference
         """
 
@@ -195,7 +191,6 @@ class HybridShapePointBetween(Point):
                 |          Dim oSupport As Reference 
                 |          Set oSupport = PointBetween.Support
 
-        :return: Reference
         :rtype: Reference
         """
 
