@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384
 
@@ -72,7 +72,6 @@ class HybridShapePointTangent(Point):
                 |          Dim oCurve As CATIAReference   
                 |          Set oCurve  = PointTangent.Curve
 
-        :return: Reference
         :rtype: Reference
         """
 
@@ -105,7 +104,6 @@ class HybridShapePointTangent(Point):
                 |          Dim oDirection As CATIAHybridShapeDirection
                 |          Set oDirection  = PointTangent.Direction
 
-        :return: HybridShapeDirection
         :rtype: HybridShapeDirection
         """
 
