@@ -19,7 +19,7 @@ from pycatia.in_interfaces.windows import Windows
 from pycatia.system_interfaces.any_object import AnyObject
 from pycatia.system_interfaces.system_service import SystemService
 from pycatia.in_interfaces.setting_controllers import SettingControllers
-from pycatia.types.document_types import document_type
+from pycatia.types.document import document_types
 
 
 class Application(AnyObject):
@@ -88,13 +88,16 @@ class Application(AnyObject):
             |          Dim ActiveDoc As Document
             |          Set ActiveDoc = CATIA.ActiveDocument
 
-        :return: Document
         :rtype: Document
         """
         try:
             active_doc_com = self.com_object.ActiveDocument
-            doc_suffix = active_doc_com.Name.split('.')[-1]
-            return document_type[doc_suffix](active_doc_com)
+            extension = active_doc_com.Name.split('.')[-1]
+            types = [document_types[k]['type'] for k in (document_types) if document_types[k]['extension'] == extension]
+            if len(types) > 1:
+                raise CATIAApplicationException('There was a problem determining the document type.')
+            document_type = types[0]
+            return document_type(active_doc_com)
         except com_error:
             raise CATIAApplicationException('Is there an active document?')
 
@@ -118,7 +121,6 @@ class Application(AnyObject):
             |          Dim ActivePrinter As Printer
             |          Set ActivePrinter = CATIA.ActivePrinter
 
-        :return: Printer
         :rtype: Printer
         """
 
@@ -152,7 +154,6 @@ class Application(AnyObject):
             |          Dim ActiveWin As Window
             |          Set ActiveWin = CATIA.ActiveWindow
 
-        :return: Window
         :rtype: Window
         """
 
@@ -178,7 +179,6 @@ class Application(AnyObject):
             |          LocalCacheSize= 10
             |          CATIA.CacheSize = LocalCacheSize
 
-        :return: int
         :rtype: int
         """
 
@@ -216,7 +216,6 @@ class Application(AnyObject):
             |
             |          CNext
 
-        :return: str
         :rtype: str
         """
 
@@ -255,7 +254,6 @@ class Application(AnyObject):
             |
             |          CATIA.DisplayFileAlerts = False
 
-        :return: bool
         :rtype: bool
         """
 
@@ -289,7 +287,6 @@ class Application(AnyObject):
             |          Dim DocCollection As Documents
             |          Set DocCollection = CATIA.Documents
 
-        :return: Documents
         :rtype: Documents
         """
         return Documents(self.com_object.Documents)
@@ -324,7 +321,6 @@ class Application(AnyObject):
             |     Product (PX1) In case this product is not granted, the first invocation to one
             |     of the methods will fail.
 
-        :return: str
         :rtype: str
         """
 
@@ -358,7 +354,6 @@ class Application(AnyObject):
             |          Dim AppliFileSys As FileSystem
             |          Set AppliFileSys = CATIA.FileSystem
 
-        :return: FileSystem
         :rtype: FileSystem
         """
 
@@ -389,7 +384,6 @@ class Application(AnyObject):
             |
             |          \\\\lisa\\cxr1arel\\bsf\\alpha_a\\code\\bin\\CNEXT.exe
 
-        :return: str
         :rtype: str
         """
 
@@ -442,7 +436,6 @@ class Application(AnyObject):
             |     interactive parts of your script: MsgBox, InputBox calls, VBA forms updates and
             |     so on.
 
-        :return: bool
         :rtype: bool
         """
 
@@ -475,7 +468,6 @@ class Application(AnyObject):
             |
             |          CATIA.Height = 300
 
-        :return: float
         :rtype: float
         """
 
@@ -509,7 +501,6 @@ class Application(AnyObject):
             |
             |          CATIA.Interactive = True
 
-        :return: bool
         :rtype: bool
         """
 
@@ -544,7 +535,6 @@ class Application(AnyObject):
             |
             |          CATIA.Left = 150
 
-        :return: float
         :rtype: float
         """
 
@@ -578,7 +568,6 @@ class Application(AnyObject):
             |          LocalCachePath= "/tmp/cache"
             |          CATIA.LocalCache = LocalCachePath
 
-        :return: str
         :rtype: str
         """
 
@@ -615,7 +604,6 @@ class Application(AnyObject):
             |
             |          \\\\lisa\\cxr1arel\\bsf\\alpha_a\\code\\bin
 
-        :return: Path
         :rtype: Path
         """
 
@@ -641,7 +629,6 @@ class Application(AnyObject):
             |          Dim PrintersCollection As Windows
             |          Set PrintersCollection = CATIA.Printers
 
-        :return: Printers
         :rtype: Printers
         """
 
@@ -671,7 +658,6 @@ class Application(AnyObject):
             |
             |          CATIA.RefreshDisplay = False
 
-        :return: bool
         :rtype: bool
         """
 
@@ -709,7 +695,6 @@ class Application(AnyObject):
             |
             |          Welcome to CATIA CxR1
 
-        :return: str
         :rtype: str
         """
 
@@ -742,7 +727,6 @@ class Application(AnyObject):
             |         oConfiguration
             |             The system configuration object.
 
-        :return: SystemConfiguration
         :rtype: SystemConfiguration
         """
 
@@ -767,7 +751,6 @@ class Application(AnyObject):
             |          Dim AppliSysSer As SystemService
             |          Set AppliSysSer = CATIA.SystemService
 
-        :return: SystemService
         :rtype: SystemService
         """
 
@@ -793,7 +776,6 @@ class Application(AnyObject):
             |
             |          CATIA.Top = 50
 
-        :return: float
         :rtype: float
         """
 
@@ -833,7 +815,6 @@ class Application(AnyObject):
             |
             |          CATIA.UndoRedoLock = True
 
-        :return: bool
         :rtype: bool
         """
 
@@ -867,7 +848,6 @@ class Application(AnyObject):
             |
             |          CATIA.Visibility = True
 
-        :return: bool
         :rtype: bool
         """
 
@@ -900,7 +880,6 @@ class Application(AnyObject):
             |
             |          CATIA.Width = 350
 
-        :return: float
         :rtype: float
         """
 
@@ -934,7 +913,6 @@ class Application(AnyObject):
             |          Dim WinCollection As Windows
             |          Set WinCollection = CATIA.Windows
 
-        :return: Windows
         :rtype: Windows
         """
 
@@ -956,7 +934,6 @@ class Application(AnyObject):
             |     In case this product is not granted, the first invocation
             |     to one of CATIASendToService methods will fail.
 
-        :return: SendToService
         :rtype: SendToService
         """
         return SendToService(self.com_object.CreateSendTo())
@@ -986,7 +963,6 @@ class Application(AnyObject):
             |
             |          CATIA.DisableNewUndoRedoTransaction()
 
-        :return: None
         :rtype: None
         """
         return self.com_object.DisableNewUndoRedoTransaction()
@@ -1008,7 +984,6 @@ class Application(AnyObject):
             |
             |          CATIA.EnableNewUndoRedoTransaction()
 
-        :return: None
         :rtype: None
         """
         return self.com_object.EnableNewUndoRedoTransaction()
@@ -1052,8 +1027,7 @@ class Application(AnyObject):
 
         :param str i_title:
         :param str i_extension:
-        :param CatFileSelectionMode i_mode:
-        :return: str
+        :param int i_mode: enum cat_file_selection_mode
         :rtype: str
         """
         return self.com_object.FileSelectionBox(i_title, i_extension, i_mode)
@@ -1074,7 +1048,6 @@ class Application(AnyObject):
             |         oworkbenchId
             |             The id of the current workbench.
 
-        :return: str
         :rtype: str
         """
         return self.com_object.GetWorkbenchId()
@@ -1102,7 +1075,6 @@ class Application(AnyObject):
             |          CATIA.Help("HelpKey")
 
         :param str i_help_id:
-        :return: None
         :rtype: None
         """
         return self.com_object.Help(i_help_id)
@@ -1188,6 +1160,37 @@ class Application(AnyObject):
             [message_text, buttons, title]
         )
 
+    def input_box(
+            self,
+            prompt: str,
+            title: str = '',
+            default: str = ''
+    ) -> str:
+        """
+        Display InputBox in catia.
+        Default position is in the center screen.
+
+        More information on
+        https://learn.microsoft.com/en-us/office/vba/language/reference/user-interface-help/inputbox-function
+
+        :param str prompt: Required. String expression displayed as the message in the dialog box.
+        :param str title: Optional. The default is ''. String expression displayed in the title bar of the dialog box.
+        :param str default: Optional. The default is ''. String expression displayed in the text box as the default
+                                      response if no other input is provided. If you omit default, the text box is
+                                      displayed empty.
+        :returns: str
+        """
+        f_name = "input_box"
+        i_box = f"Public Function {f_name}(prompt,title,default)\n" \
+                f"    {f_name} = InputBox(prompt,title,default)\n" \
+                "End Function"
+        return self.system_service.evaluate(
+            i_box,
+            cat_script_language.index('CATVBScriptLanguage'),
+            f_name,
+            [prompt, title, default]
+        )
+
     def quit(self) -> None:
         """
         .. note::
@@ -1205,12 +1208,11 @@ class Application(AnyObject):
             |
             |          CATIA.Quit()
 
-        :return: None
         :rtype: None
         """
         return self.com_object.Quit()
 
-    def setting_controllers(self):
+    def setting_controllers(self) -> SettingControllers:
         """
         Application.SettingControllers
         """
@@ -1239,7 +1241,6 @@ class Application(AnyObject):
             |             command or its alias.
 
         :param str i_command_id:
-        :return: None
         :rtype: None
         """
         return self.com_object.StartCommand(i_command_id)
@@ -1261,7 +1262,6 @@ class Application(AnyObject):
             |             The id of the workbench to be started.
 
         :param str iworkbench_id:
-        :return: None
         :rtype: None
         """
         return self.com_object.StartWorkbench(iworkbench_id)
