@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -13,7 +13,6 @@ from pycatia.system_interfaces.setting_controller import SettingController
 
 
 class DocumentationSettingAtt(SettingController):
-
     """
         .. note::
             :class: toggle
@@ -49,7 +48,6 @@ class DocumentationSettingAtt(SettingController):
                 | 
                 |     Returns the User Companion location (path) parameter.
 
-        :return: str
         :rtype: str
         """
 
@@ -74,7 +72,6 @@ class DocumentationSettingAtt(SettingController):
                 | 
                 |     Returns the technical documentation language parameter.
 
-        :return: int
         :rtype: int
         """
 
@@ -99,7 +96,7 @@ class DocumentationSettingAtt(SettingController):
                 | 
                 |     Returns the contextual priority parameter.
 
-        :return: int
+        :return: enum cat_doc_contextual_priority
         :rtype: int
         """
 
@@ -108,7 +105,7 @@ class DocumentationSettingAtt(SettingController):
     @priority.setter
     def priority(self, value: int):
         """
-        :param int value:
+        :param int value: enum cat_doc_contextual_priority
         """
 
         self.documentation_setting_att.Priority = value
@@ -124,7 +121,6 @@ class DocumentationSettingAtt(SettingController):
                 | 
                 |     Returns the technical documentation location (path) parameter.
 
-        :return: str
         :rtype: str
         """
 
@@ -170,7 +166,6 @@ class DocumentationSettingAtt(SettingController):
 
         :param str io_admin_level:
         :param str io_locked:
-        :return: bool
         :rtype: bool
         """
         return self.documentation_setting_att.GetCompanionPathInfo(io_admin_level, io_locked)
@@ -207,7 +202,6 @@ class DocumentationSettingAtt(SettingController):
 
         :param str io_admin_level:
         :param str io_locked:
-        :return: bool
         :rtype: bool
         """
         return self.documentation_setting_att.GetDocLanguageInfo(io_admin_level, io_locked)
@@ -244,7 +238,6 @@ class DocumentationSettingAtt(SettingController):
 
         :param str io_admin_level:
         :param str io_locked:
-        :return: bool
         :rtype: bool
         """
         return self.documentation_setting_att.GetPriorityInfo(io_admin_level, io_locked)
@@ -282,7 +275,6 @@ class DocumentationSettingAtt(SettingController):
 
         :param str io_admin_level:
         :param str io_locked:
-        :return: bool
         :rtype: bool
         """
         return self.documentation_setting_att.GetTechnicalDocumentationPathInfo(io_admin_level, io_locked)
@@ -309,7 +301,6 @@ class DocumentationSettingAtt(SettingController):
                 |             FALSE: to unlock the parameter.
 
         :param bool i_locked:
-        :return: None
         :rtype: None
         """
         return self.documentation_setting_att.SetCompanionPathLock(i_locked)
@@ -352,7 +343,6 @@ class DocumentationSettingAtt(SettingController):
                 |             FALSE: to unlock the parameter.
 
         :param bool i_locked:
-        :return: None
         :rtype: None
         """
         return self.documentation_setting_att.SetDocLanguageLock(i_locked)
@@ -394,7 +384,6 @@ class DocumentationSettingAtt(SettingController):
                 |             FALSE: to unlock the parameter.
 
         :param bool i_locked:
-        :return: None
         :rtype: None
         """
         return self.documentation_setting_att.SetPriorityLock(i_locked)
@@ -437,7 +426,6 @@ class DocumentationSettingAtt(SettingController):
                 |             FALSE: to unlock the parameter.
 
         :param bool i_locked:
-        :return: None
         :rtype: None
         """
         return self.documentation_setting_att.SetTechnicalDocumentationPathLock(i_locked)
@@ -458,4 +446,4 @@ class DocumentationSettingAtt(SettingController):
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
-        return f'DocumentationSettingAtt(name="{ self.name }")'
+        return f'DocumentationSettingAtt(name="{self.name}")'
