@@ -8,9 +8,8 @@ from pywintypes import com_error
 from pycatia.exception_handling import CATIAApplicationException
 from pycatia.in_interfaces.document import Document
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types.document_types import document_type
+from pycatia.types.document import document_types
 from pycatia.types.general import cat_variant, list_str
-from pycatia.scripts.document_types import get_document_type
 
 
 class Documents(Collection):
@@ -84,19 +83,17 @@ class Documents(Collection):
                 |          Set PartDoc = Documents.Add("Part")
 
         :param str document_type:
-        :return: Document
         :rtype: Document
         """
 
-        # document_types = ['Part', 'Product', 'Drawing', 'FunctionalSystem']
-        # if document_type not in document_types:
-        #     raise ValueError(f'Document type {document_type} must be in {document_types}')
+        # see pycatia.types.docs for supported Documents.
 
-        dt = get_document_type(document_type)
+        if document_type.lower() not in [t.lower() for t in document_types]:
+            raise CATIAApplicationException(f'Document type {document_type} not supported. Allowed types are {[t for t in document_types]}.')
 
-        self.logger.info(f'Creating a new "{dt}".')
+        document = document_types[document_type]['type']
 
-        return Document(self.documents.Add(dt))
+        return document(self.documents.Add(document_type))
 
     def count_types(self, file_type_list: list_str) -> int:
         """
@@ -149,7 +146,6 @@ class Documents(Collection):
                 |          Set Doc = Documents.NewFrom(FileToRead)
 
         :param str file_name:
-        :return: Document
         :rtype: Document
         """
 
@@ -194,7 +190,6 @@ class Documents(Collection):
                 |          Set ThatDoc = Documents.Item("MyDoc")
 
         :param cat_variant index:
-        :return: Document
         :rtype: Document
         """
         try:
@@ -211,7 +206,6 @@ class Documents(Collection):
             The COM object can return the incorrect number of documents open. After a document is closed CATIA can keep
             the linked document `ABQMaterialPropertiesCatalog.CATfct` open.
 
-        :return: int
         :rtype: int
         """
 
@@ -256,7 +250,6 @@ class Documents(Collection):
                 |          Set Doc = Documents.Open(FileToOpen)
 
         :param str file_name:
-        :return: Document
         :rtype: Document
         """
 
@@ -307,24 +300,23 @@ class Documents(Collection):
                 |          Set Doc = Documents.Read(FileToOpen)
 
         :param str file_name:
-        :return: Document
         :rtype: Document
         """
         # return Document(self.documents.Read(file_name))
 
         read_doc_com = self.documents.Read(file_name)
         doc_suffix = file_name.split('.')[-1]
-        return document_type[doc_suffix](read_doc_com)
+        return document_types[doc_suffix](read_doc_com)
 
     def __getitem__(self, n: int) -> Document:
         if (n + 1) > self.count:
             raise StopIteration
 
-        return Document(self.documents.item(n + 1))
+        return Document(self.documents.Item(n + 1))
 
     def __iter__(self) -> Iterator[Document]:
         for i in range(self.count):
-            yield self.child_object(self.com_object.item(i + 1))
+            yield self.child_object(self.com_object.Item(i + 1))
 
     def __repr__(self):
         return f'Documents(name="{self.name}")'
