@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -58,7 +58,6 @@ class FileComponent(AnyObject):
                 | 
                 |          TestFile.ParentFolder
 
-        :return: Folder
         :rtype: Folder
         """
         from pycatia.in_interfaces.folder import Folder
@@ -90,7 +89,6 @@ class FileComponent(AnyObject):
                 |          Dim FilePath As String
                 |          FilePath = TestFile.Path
 
-        :return: str
         :rtype: str
         """
 
