@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -13,7 +13,6 @@ from pycatia.system_interfaces.setting_controller import SettingController
 
 
 class GeneralSessionSettingAtt(SettingController):
-
     """
         .. note::
             :class: toggle
@@ -49,7 +48,7 @@ class GeneralSessionSettingAtt(SettingController):
                 | 
                 |     Returns the data save parameter.
 
-        :return: int
+        :return: enum cat_gen_data_save
         :rtype: int
         """
 
@@ -58,7 +57,7 @@ class GeneralSessionSettingAtt(SettingController):
     @auto_save.setter
     def auto_save(self, value: int):
         """
-        :param int value:
+        :param int value: enum cat_gen_data_save
         """
 
         self.general_session_setting_att.AutoSave = value
@@ -74,7 +73,7 @@ class GeneralSessionSettingAtt(SettingController):
                 | 
                 |     Returns the conference driver parameter.
 
-        :return: int
+        :return: enum cat_gen_conferencing
         :rtype: int
         """
 
@@ -83,7 +82,7 @@ class GeneralSessionSettingAtt(SettingController):
     @conferencing.setter
     def conferencing(self, value: int):
         """
-        :param int value:
+        :param int value: enum cat_gen_conferencing
         """
 
         self.general_session_setting_att.Conferencing = value
@@ -99,7 +98,6 @@ class GeneralSessionSettingAtt(SettingController):
                 | 
                 |     Returns the drag & drop parameter.
 
-        :return: bool
         :rtype: bool
         """
 
@@ -124,7 +122,6 @@ class GeneralSessionSettingAtt(SettingController):
                 | 
                 |     Returns the referenced documents parameter.
 
-        :return: bool
         :rtype: bool
         """
 
@@ -149,7 +146,6 @@ class GeneralSessionSettingAtt(SettingController):
                 | 
                 |     Returns the data save parameter (in milliseconds).
 
-        :return: int
         :rtype: int
         """
 
@@ -174,7 +170,7 @@ class GeneralSessionSettingAtt(SettingController):
                 | 
                 |     Returns the user interface style parameter.
 
-        :return: int
+        :return: enum cat_gen_ui_style
         :rtype: int
         """
 
@@ -183,7 +179,7 @@ class GeneralSessionSettingAtt(SettingController):
     @ui_style.setter
     def ui_style(self, value: int):
         """
-        :param int value:
+        :param int value: enum cat_gen_ui_style
         """
 
         self.general_session_setting_att.UIStyle = value
@@ -220,7 +216,6 @@ class GeneralSessionSettingAtt(SettingController):
 
         :param str io_admin_level:
         :param str io_locked:
-        :return: bool
         :rtype: bool
         """
         return self.general_session_setting_att.GetAutoSaveInfo(io_admin_level, io_locked)
@@ -257,7 +252,6 @@ class GeneralSessionSettingAtt(SettingController):
 
         :param str io_admin_level:
         :param str io_locked:
-        :return: bool
         :rtype: bool
         """
         return self.general_session_setting_att.GetConferencingInfo(io_admin_level, io_locked)
@@ -294,7 +288,6 @@ class GeneralSessionSettingAtt(SettingController):
 
         :param str io_admin_level:
         :param str io_locked:
-        :return: bool
         :rtype: bool
         """
         return self.general_session_setting_att.GetDragDropInfo(io_admin_level, io_locked)
@@ -331,7 +324,6 @@ class GeneralSessionSettingAtt(SettingController):
 
         :param str io_admin_level:
         :param str io_locked:
-        :return: bool
         :rtype: bool
         """
         return self.general_session_setting_att.GetRefDocInfo(io_admin_level, io_locked)
@@ -368,7 +360,6 @@ class GeneralSessionSettingAtt(SettingController):
 
         :param str io_admin_level:
         :param str io_locked:
-        :return: bool
         :rtype: bool
         """
         return self.general_session_setting_att.GetUIStyleInfo(io_admin_level, io_locked)
@@ -395,7 +386,6 @@ class GeneralSessionSettingAtt(SettingController):
                 |             FALSE: to unlock the parameter.
 
         :param bool i_locked:
-        :return: None
         :rtype: None
         """
         return self.general_session_setting_att.SetAutoSaveLock(i_locked)
@@ -437,7 +427,6 @@ class GeneralSessionSettingAtt(SettingController):
                 |             FALSE: to unlock the parameter.
 
         :param bool i_locked:
-        :return: None
         :rtype: None
         """
         return self.general_session_setting_att.SetConferencingLock(i_locked)
@@ -479,7 +468,6 @@ class GeneralSessionSettingAtt(SettingController):
                 |             FALSE: to unlock the parameter.
 
         :param bool i_locked:
-        :return: None
         :rtype: None
         """
         return self.general_session_setting_att.SetDragDropLock(i_locked)
@@ -521,7 +509,6 @@ class GeneralSessionSettingAtt(SettingController):
                 |             FALSE: to unlock the parameter.
 
         :param bool i_locked:
-        :return: None
         :rtype: None
         """
         return self.general_session_setting_att.SetRefDocLock(i_locked)
@@ -563,7 +550,6 @@ class GeneralSessionSettingAtt(SettingController):
                 |             FALSE: to unlock the parameter.
 
         :param bool i_locked:
-        :return: None
         :rtype: None
         """
         return self.general_session_setting_att.SetUIStyleLock(i_locked)
@@ -584,4 +570,4 @@ class GeneralSessionSettingAtt(SettingController):
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
-        return f'GeneralSessionSettingAtt(name="{ self.name }")'
+        return f'GeneralSessionSettingAtt(name="{self.name}")'
