@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -59,7 +59,6 @@ class Reference(AnyObject):
                 |
                 |          StrName = FirstRef.DisplayName
 
-        :return: str
         :rtype: str
         """
 
@@ -91,7 +90,6 @@ class Reference(AnyObject):
                 |                  Set CompositeRef = FirstRef.ComposeWith(SecondRef)
 
         :param Reference i_reference:
-        :return: Reference
         :rtype: Reference
         """
         return Reference(self.reference.ComposeWith(i_reference.com_object))
