@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -60,8 +60,7 @@ class Windows(Collection):
                 | 
                 |          CATIA.Windows.Arrange(catArrangeCascade)
 
-        :param int i_style:
-        :return: None
+        :param int i_style: enum cat_arrange_style
         :rtype: None
         """
         return self.windows.Arrange(i_style)
@@ -99,7 +98,6 @@ class Windows(Collection):
                 |          Set ThatWindow = CATIA.Windows.Item("MyWindow")
 
         :param cat_variant i_index:
-        :return: Window
         :rtype: Window
         """
         return Window(self.windows.Item(i_index))
@@ -108,11 +106,11 @@ class Windows(Collection):
         if (n + 1) > self.count:
             raise StopIteration
 
-        return Window(self.windows.item(n + 1))
+        return Window(self.windows.Item(n + 1))
 
     def __iter__(self) -> Iterator[Window]:
         for i in range(self.count):
-            yield self.child_object(self.com_object.item(i + 1))
+            yield self.child_object(self.com_object.Item(i + 1))
 
     def __repr__(self):
         return f'Windows(name="{self.name}")'
