@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -54,7 +54,6 @@ class FreeParameters(Collection):
                 |     Adds a free parameter. This parameter must not be read only.
 
         :param RealParam parameter:
-        :return: FreeParameter
         :rtype: FreeParameter
         """
         return FreeParameter(self.free_parameters.AddFreeParameter(parameter.com_object))
@@ -91,7 +90,6 @@ class FreeParameters(Collection):
                 |          Set lastFreeParameter = freeParameters.Item(freeParameters.Count)
 
         :param cat_variant i_index:
-        :return: FreeParameter
         :rtype: FreeParameter
         """
         return FreeParameter(self.free_parameters.Item(i_index))
@@ -115,11 +113,11 @@ class FreeParameters(Collection):
         if (n + 1) > self.count:
             raise StopIteration
 
-        return FreeParameter(self.free_parameters.item(n + 1))
+        return FreeParameter(self.free_parameters.Item(n + 1))
 
     def __iter__(self) -> Iterator[FreeParameter]:
         for i in range(self.count):
-            yield self.child_object(self.com_object.item(i + 1))
+            yield self.child_object(self.com_object.Item(i + 1))
 
     def __repr__(self):
         return f'FreeParameters(name="{self.name}")'
