@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -68,7 +68,6 @@ class ParameterSets(Collection):
                 |     corresponds to this collection.
 
         :param str i_name:
-        :return: ParameterSet
         :rtype: ParameterSet
         """
         return ParameterSet(self.parameter_sets.CreateSet(i_name))
@@ -102,7 +101,6 @@ class ParameterSets(Collection):
                 |          Set theSet = parameterSets.Item("Parameters.1")
 
         :param cat_variant i_index:
-        :return: ParameterSet
         :rtype: ParameterSet
         """
         return ParameterSet(self.parameter_sets.Item(i_index))
@@ -111,11 +109,11 @@ class ParameterSets(Collection):
         if (n + 1) > self.count:
             raise StopIteration
 
-        return ParameterSet(self.parameter_sets.item(n + 1))
+        return ParameterSet(self.parameter_sets.Item(n + 1))
 
     def __iter__(self) -> Iterator[ParameterSet]:
         for i in range(self.count):
-            yield self.child_object(self.com_object.item(i + 1))
+            yield self.child_object(self.com_object.Item(i + 1))
 
     def __repr__(self):
         return f'ParameterSets(name="{self.name}")'
