@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -57,7 +57,6 @@ class FixTogethers(Collection):
                 | 
                 |          Set newFixTogether = fixTogethers.Add
 
-        :return: FixTogether
         :rtype: FixTogether
         """
         return FixTogether(self.fix_togethers.Add())
@@ -96,7 +95,6 @@ class FixTogethers(Collection):
                 |          Set thatFixTogether = fixTogetherColl.Item("MyFixTogether")
 
         :param cat_variant i_index:
-        :return: FixTogether
         :rtype: FixTogether
         """
         return FixTogether(self.fix_togethers.Item(i_index))
@@ -130,7 +128,6 @@ class FixTogethers(Collection):
                 |      fixTogetherColl.Remove(fixTogetherColl.Count)
 
         :param cat_variant i_index:
-        :return: None
         :rtype: None
         """
         return self.fix_togethers.Remove(i_index)
@@ -139,11 +136,11 @@ class FixTogethers(Collection):
         if (n + 1) > self.count:
             raise StopIteration
 
-        return FixTogether(self.fix_togethers.item(n + 1))
+        return FixTogether(self.fix_togethers.Item(n + 1))
 
     def __iter__(self) -> Iterator[FixTogether]:
         for i in range(self.count):
-            yield self.child_object(self.com_object.item(i + 1))
+            yield self.child_object(self.com_object.Item(i + 1))
 
     def __repr__(self):
         return f'FixTogethers(name="{self.name}")'
