@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -76,7 +76,6 @@ class GeometricElements(Collection):
                 |          Set lastCst = cstList.Item(cstList.Count)
 
         :param cat_variant i_index:
-        :return: GeometricElement
         :rtype: GeometricElement
         """
         return GeometricElement(self.geometric_elements.Item(i_index))
@@ -85,11 +84,11 @@ class GeometricElements(Collection):
         if (n + 1) > self.count:
             raise StopIteration
 
-        return GeometricElement(self.geometric_elements.item(n + 1))
+        return GeometricElement(self.geometric_elements.Item(n + 1))
 
     def __iter__(self) -> Iterator[GeometricElement]:
         for i in range(self.count):
-            yield self.child_object(self.com_object.item(i + 1))
+            yield self.child_object(self.com_object.Item(i + 1))
 
     def __repr__(self):
         return f'GeometricElements(name="{self.name}")'
