@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -65,7 +65,6 @@ class PartDocument(Document):
                 | 
                 |          Set RootPart = CATIA.ActiveDocument.Part
 
-        :return: Part
         :rtype: Part
         """
 
@@ -89,7 +88,6 @@ class PartDocument(Document):
                 | 
                 |          Set RootProd = CATIA.ActiveDocument.Part
 
-        :return: Product
         :rtype: Product
         """
 
