@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -69,7 +69,6 @@ class Sketches(Collection):
                 |          Set newSketch = myPart.Sketches.Add(XYPlane)
 
         :param Reference i_plane:
-        :return: Sketch
         :rtype: Sketch
         """
         return Sketch(self.sketches.Add(i_plane.com_object))
@@ -94,7 +93,6 @@ class Sketches(Collection):
                 |         The retrieved boundary
 
         :param str i_label:
-        :return: Boundary
         :rtype: Boundary
         """
         return Boundary(self.sketches.GetBoundary(i_label))
@@ -129,7 +127,6 @@ class Sketches(Collection):
                 |          Set lastSketch = sketchList.Item(sketchList.Count)
 
         :param cat_variant i_index:
-        :return: Sketch
         :rtype: Sketch
         """
         return Sketch(self.sketches.Item(i_index))
@@ -138,11 +135,11 @@ class Sketches(Collection):
         if (n + 1) > self.count:
             raise StopIteration
 
-        return Sketch(self.sketches.item(n + 1))
+        return Sketch(self.sketches.Item(n + 1))
 
     def __iter__(self) -> Iterator[Sketch]:
         for i in range(self.count):
-            yield self.child_object(self.com_object.item(i + 1))
+            yield self.child_object(self.com_object.Item(i + 1))
 
     def __repr__(self):
         return f'Sketches(name="{self.name}")'
