@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -74,7 +74,6 @@ class Solid(Shape):
                 |     See also:
                 |         Move
 
-        :return: Move
         :rtype: Move
         """
 
@@ -98,7 +97,6 @@ class Solid(Shape):
                 | 
                 |          Set element = importedSolid.SourceElement
 
-        :return: AnyObject
         :rtype: AnyObject
         """
 
@@ -123,7 +121,6 @@ class Solid(Shape):
                 | 
                 |          Set prod1 = importedSolid.SourceProduct
 
-        :return: AnyObject
         :rtype: AnyObject
         """
 
