@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -65,7 +65,6 @@ class DMUReview(AnyObject):
                 |             Activation = oDMUReview.Activation
                 |             oDMUReview.Activation = 1
 
-        :return: int
         :rtype: int
         """
 
@@ -99,7 +98,6 @@ class DMUReview(AnyObject):
                 | 
                 |             Set cDMUReviews = oDMUReview.DMUReviews(9)
 
-        :return: DMUReviews
         :rtype: DMUReviews
         """
         from pycatia.navigator_interfaces.dmu_reviews import DMUReviews
