@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -15,7 +15,6 @@ from pycatia.part_interfaces.dress_up_shape import DressUpShape
 
 
 class AutoDraft(DressUpShape):
-
     """
         .. note::
             :class: toggle
@@ -40,7 +39,7 @@ class AutoDraft(DressUpShape):
         self.auto_draft = com_object
 
     @property
-    def functional_face(self) -> None:
+    def functional_face(self) -> Reference:
         """
         .. note::
             :class: toggle
@@ -48,11 +47,10 @@ class AutoDraft(DressUpShape):
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property FunctionalFace(Reference iFace) (Write Only)
 
-        :return: None
-        :rtype: None
+        :rtype: Reference
         """
 
-        return None
+        return Reference(self.auto_draft.FunctionalFace)
 
     @functional_face.setter
     def functional_face(self, reference: Reference):
@@ -60,7 +58,7 @@ class AutoDraft(DressUpShape):
         :param Reference reference:
         """
 
-        self.auto_draft.FunctionalFace = reference
+        self.auto_draft.FunctionalFace = reference.com_object
 
     @property
     def functional_faces(self) -> References:
@@ -81,7 +79,6 @@ class AutoDraft(DressUpShape):
                 |          Set FunctionalFaces = AutoDraft.FunctionalFace
                 |          AutoDraft.FunctionalFace = NewFunctionalFace
 
-        :return: References
         :rtype: References
         """
 
@@ -106,7 +103,6 @@ class AutoDraft(DressUpShape):
                 |          Set MainDraftAngle = AutoDraft.MainDraftAngle
                 |          AutoDraft.MainDraftAngle = NewMainDraftAngle
 
-        :return: Reference
         :rtype: Reference
         """
 
@@ -138,7 +134,6 @@ class AutoDraft(DressUpShape):
                 |          Set Mode = AutoDraft.Mode
                 |          AutoDraft.Mode = NewMode
 
-        :return: Reference
         :rtype: Reference
         """
 
@@ -171,7 +166,6 @@ class AutoDraft(DressUpShape):
                 |          Set PartingElement = AutoDraft.PartingElement
                 |          AutoDraft.PartingElement = NewPartingElement
 
-        :return: Reference
         :rtype: Reference
         """
 
@@ -204,7 +198,6 @@ class AutoDraft(DressUpShape):
                 |          Set PullingDirection = AutoDraft.PullingDirection
                 |          AutoDraft.PullingDirection = NewPullingDirection
 
-        :return: Reference
         :rtype: Reference
         """
 
