@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -61,7 +61,6 @@ class Chamfer(DressUpShape):
                 | 
                 |          Set angle = firstChamfer.Angle
 
-        :return: Angle
         :rtype: Angle
         """
 
@@ -85,7 +84,6 @@ class Chamfer(DressUpShape):
                 | 
                 |          Set list = firstChamfer.ElementsToChamfer
 
-        :return: References
         :rtype: References
         """
 
@@ -110,7 +108,6 @@ class Chamfer(DressUpShape):
                 | 
                 |          Set length1 = firstChamfer.Length1
 
-        :return: Length
         :rtype: Length
         """
 
@@ -135,7 +132,6 @@ class Chamfer(DressUpShape):
                 | 
                 |          Set length2 = firstChamfer.Length2
 
-        :return: Length
         :rtype: Length
         """
 
@@ -162,7 +158,7 @@ class Chamfer(DressUpShape):
                 |          Set mode = firstChamfer.Mode
                 |          firstChamfer.Mode = catTwoLengthChamfer
 
-        :return: int
+        :return: enum cat_chamfer_mode
         :rtype: int
         """
 
@@ -171,7 +167,7 @@ class Chamfer(DressUpShape):
     @mode.setter
     def mode(self, value: int):
         """
-        :param int value:
+        :param int value: enum cat_chamfer_mode
         """
 
         self.chamfer.Mode = value
@@ -195,7 +191,7 @@ class Chamfer(DressUpShape):
                 |          Set orient = firstChamfer.Orientation
                 |          firstChamfer.Orientation = catReverseChamfer
 
-        :return: int
+        :return: enum cat_chamfer_orientation
         :rtype: int
         """
 
@@ -204,7 +200,7 @@ class Chamfer(DressUpShape):
     @orientation.setter
     def orientation(self, value: int):
         """
-        :param int value:
+        :param int value: enum cat_chamfer_orientation
         """
 
         self.chamfer.Orientation = value
@@ -229,7 +225,7 @@ class Chamfer(DressUpShape):
                 |          Set prop = firstChamfer.Propagation
                 |          firstChamfer.Propagation = catMinimalChamfer
 
-        :return: int
+        :return: enum cat_chamfer_orientation
         :rtype: int
         """
 
@@ -268,7 +264,6 @@ class Chamfer(DressUpShape):
                 |      firstChamfer.AddElementToChamfer(element)
 
         :param Reference i_element_to_chamfer:
-        :return: None
         :rtype: None
         """
         return self.chamfer.AddElementToChamfer(i_element_to_chamfer.com_object)
@@ -314,7 +309,6 @@ class Chamfer(DressUpShape):
                 |      firstChamfer.WithdrawElementToChamfer(element)
 
         :param Reference i_element_to_withdraw:
-        :return: None
         :rtype: None
         """
         return self.chamfer.WithdrawElementToChamfer(i_element_to_withdraw.com_object)
