@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -86,7 +86,6 @@ class Product(AnyObject):
                 |          Dim EngineAnalysis As Analyze
                 |          Set EngineAnalysis = Engine.Analyze
 
-        :return: Analyze
         :rtype: Analyze
         """
 
@@ -112,7 +111,6 @@ class Product(AnyObject):
                 |
                 |          EngineDef = Engine.Definition
 
-        :return: str
         :rtype: str
         """
 
@@ -150,7 +148,6 @@ class Product(AnyObject):
                 |          Desc = "This is the Engine component product description"
                 |          EngineComp.DescriptionInst(Desc)
 
-        :return: str
         :rtype: str
         """
 
@@ -188,7 +185,6 @@ class Product(AnyObject):
                 |          Desc = "This is the Engine reference product description"
                 |          Engine.DescriptionRef(Desc)
 
-        :return: str
         :rtype: str
         """
 
@@ -268,7 +264,6 @@ class Product(AnyObject):
                 |
                 |          EngineNom = Engine.Nomenclature
 
-        :return: str
         :rtype: str
         """
 
@@ -303,7 +298,6 @@ class Product(AnyObject):
                 |          Set productRoot = productDoc.Product
                 |          Set params = productRoot.Parameters
 
-        :return: Parameters
         :rtype: Parameters
         """
 
@@ -329,13 +323,13 @@ class Product(AnyObject):
                 |
                 |          Engine.PartNumber("A120-253X-7")
 
-        :return: str
         :rtype: str
         """
         try:
             return self.product.PartNumber
         except com_error:
-            raise CATIAApplicationException(f'Prodcut "{self.name}" could not do get Product.PartNumber. Check Product for broken links.')
+            raise CATIAApplicationException(
+                f'Prodcut "{self.name}" could not do get Product.PartNumber. Check Product for broken links.')
 
     @part_number.setter
     def part_number(self, value: str):
@@ -346,7 +340,8 @@ class Product(AnyObject):
         try:
             self.product.PartNumber = value
         except com_error:
-            raise CATIAApplicationException(f'Prodcut "{self.name}" could not do set Product.PartNumber. Check Product for broken links.')
+            raise CATIAApplicationException(
+                f'Prodcut "{self.name}" could not do set Product.PartNumber. Check Product for broken links.')
 
     @property
     def position(self) -> Position:
@@ -370,7 +365,6 @@ class Product(AnyObject):
                 |          Dim EnginePositionObject As Position
                 |          Set EnginePositionObject = Engine.Position
 
-        :return: Position
         :rtype: Position
         """
 
@@ -398,7 +392,6 @@ class Product(AnyObject):
                 |          Dim EngineChildren As Products
                 |          Set EngineChildren = Engine.Products
 
-        :return: Products
         :rtype: Products
         """
         from pycatia.product_structure_interfaces.products import Products
@@ -415,7 +408,6 @@ class Product(AnyObject):
                 |
                 |     Returns the collection of publications managed by the product.
 
-        :return: Publications
         :rtype: Publications
         """
 
@@ -432,13 +424,13 @@ class Product(AnyObject):
                 |
                 |     Returns the Reference Product of this instance.
 
-        :return: Product
         :rtype: Product
         """
         try:
             return Product(self.product.ReferenceProduct)
         except com_error:
-            raise CATIAApplicationException(f'Prodcut "{self.name}" could not do get Reference Product. Check Product for broken links.')
+            raise CATIAApplicationException(
+                f'Product "{self.name}" could not do get Reference Product. Check Product for broken links.')
 
     @property
     def relations(self) -> Relations:
@@ -460,7 +452,6 @@ class Product(AnyObject):
                 |          Set productRoot = productDoc.Product
                 |          Set rels = productRoot.Relations
 
-        :return: Relations
         :rtype: Relations
         """
 
@@ -486,7 +477,6 @@ class Product(AnyObject):
                 |
                 |          Engine.Revision("3A")
 
-        :return: str
         :rtype: str
         """
 
@@ -525,35 +515,36 @@ class Product(AnyObject):
                 |
                 |          Engine.Source(catProductMade)
 
-        :return: int
+        :return: enum cat_product_source
         :rtype: int
         """
 
         try:
             return self.product.Source
         except com_error:
-            raise CATIAApplicationException(f'Prodcut "{self.name}" could not do get Product.Source. Check Product for broken links.')
+            raise CATIAApplicationException(
+                f'Prodcut "{self.name}" could not do get Product.Source. Check Product for broken links.')
 
     @source.setter
     def source(self, value: int):
         """
-        :param int value:
+        :param int value: enum cat_product_source
         """
 
         try:
             self.product.Source = value
         except com_error:
-            raise CATIAApplicationException(f'Prodcut "{self.name}" could not do set Product.Source. Check Product for broken links.')
+            raise CATIAApplicationException(
+                f'Prodcut "{self.name}" could not do set Product.Source. Check Product for broken links.')
 
     @property
     def type(self) -> str:
         """
         Returns the type of product (CATProduct, CATPart or Component).
 
-        :return: str
         :rtype: str
         """
-        
+
         root_product_name = self.reference_product.com_object.Parent.Product.Name
         self_product_name = self.reference_product.name
         if root_product_name == self_product_name:
@@ -583,7 +574,6 @@ class Product(AnyObject):
                 |          Set productRoot = productDoc.Product
                 |          Set UserProps = productRoot.UserRefProperties
 
-        :return: Parameters
         :rtype: Parameters
         """
 
@@ -599,7 +589,6 @@ class Product(AnyObject):
                 |
                 |     Activate default shape.
 
-        :return: None
         :rtype: None
         """
         return self.product.ActivateDefaultShape()
@@ -620,7 +609,6 @@ class Product(AnyObject):
                 |             The name of the shape.
 
         :param str shape_name:
-        :return: None
         :rtype: None
         """
         return self.product.ActivateShape(shape_name)
@@ -639,7 +627,7 @@ class Product(AnyObject):
                 if product.is_catpart():
                     product.activate_default_shape()
                 elif product.is_catproduct():
-                    loop_d_loop(product.get_products())
+                    loop_d_loop(product.products)
 
         loop_d_loop(products)
 
@@ -731,9 +719,8 @@ class Product(AnyObject):
 
         :param str i_shape_path_name:
         :param str i_shape_name:
-        :param int i_rep_behavior:
+        :param int i_rep_behavior: enum cat_rep_type
         :param bool i_context:
-        :return: None
         :rtype: None
         """
         return self.product.AddShapeRepresentation(
@@ -773,8 +760,7 @@ class Product(AnyObject):
                 |         newMode
                 |             The new working mode.
 
-        :param int new_mode:
-        :return: None
+        :param int new_mode: enum cat_work_mode_type
         :rtype: None
         """
         return self.product.ApplyWorkMode(new_mode)
@@ -868,7 +854,6 @@ class Product(AnyObject):
                 |          )
 
         :param str i_label:
-        :return: Reference
         :rtype: Reference
         """
         return Reference(self.product.CreateReferenceFromName(i_label))
@@ -883,7 +868,6 @@ class Product(AnyObject):
                 |
                 |     Deactivate default shape.
 
-        :return: None
         :rtype: None
         """
         return self.product.DesactivateDefaultShape()
@@ -904,7 +888,6 @@ class Product(AnyObject):
                 |             The name of the shape.
 
         :param str shape_name:
-        :return: None
         :rtype: None
         """
         return self.product.DesactivateShape(shape_name)
@@ -933,9 +916,8 @@ class Product(AnyObject):
                 |         iFile
                 |             File where the bill of material will be saved
 
-        :param int i_file_type:
+        :param int i_file_type: enum cat_file_type
         :param str i_file:
-        :return: None
         :rtype: None
         """
         return self.product.ExtractBOM(i_file_type, i_file)
@@ -969,7 +951,6 @@ class Product(AnyObject):
         Generate an ALLCATPart (CATPart) from CATProduct.
 
         :param Product product:
-        :return: Document
         :rtype: Document
         """
 
@@ -1013,7 +994,6 @@ class Product(AnyObject):
                 |         with a size given by GetNumberOfShapes.
 
         :param tuple olistshape:
-        :return: None
         :rtype: None
         """
         return self.product.GetAllShapesNames(olistshape)
@@ -1098,7 +1078,6 @@ class Product(AnyObject):
                 |          Set MSRep = Engine.GetMasterShapeRepresentation(True)
 
         :param bool i_load_if_necessary:
-        :return: AnyObject
         :rtype: AnyObject
         """
         return self.product.GetMasterShapeRepresentation(i_load_if_necessary)
@@ -1122,7 +1101,6 @@ class Product(AnyObject):
                 |
                 |          Set MSRepPath = Engine.GetMasterShapeRepresentationPathName
 
-        :return: str
         :rtype: str
         """
         return self.product.GetMasterShapeRepresentationPathName()
@@ -1140,30 +1118,10 @@ class Product(AnyObject):
                 |     Returns:
                 |         oNbShapes The number of Shapes.
 
-        :return: int
         :rtype: int
         """
         return self.product.GetNumberOfShapes()
 
-    def get_products(self):
-        """
-        Returns a list of Product().
-        :return: [Product()]
-        """
-
-        warnings.warn(
-            'This method will be deprecated in a future release. Use Product.products instead.',
-            DeprecationWarning,
-            stacklevel=2)
-
-        products_ = []
-
-        for i in range(0, self.product.Products.Count):
-            product = Product(self.product.Products.Item(i + 1))
-            products_.append(product)
-
-        return products_
-
     def get_shape_path_name(self, i_shape_name=None):
         """
         .. note::
@@ -1230,7 +1188,7 @@ class Product(AnyObject):
 
         :param bool i_load_if_necessary:
         :param str i_shape_name:
-        :param CatRepType i_rep_behavior:
+        :param int i_rep_behavior: enum cat_rep_type
         :param bool i_context:
         :return: AnyObject
         """
@@ -1269,7 +1227,6 @@ class Product(AnyObject):
                 |          Set EngineConstraints = Engine.GetTechnologicalObject("Constraints")
 
         :param str i_application_type:
-        :return: AnyObject
         :rtype: AnyObject
         """
         return self.product.GetTechnologicalObject(i_application_type)
@@ -1294,7 +1251,6 @@ class Product(AnyObject):
                 |
                 |          HasMSRep = Engine.HasAMasterShapeRepresentation()
 
-        :return: bool
         :rtype: bool
         """
         return self.product.HasAMasterShapeRepresentation()
@@ -1345,16 +1301,14 @@ class Product(AnyObject):
                 |          HasRep = Engine.HasRepresentation("PART",catRep3D,TRUE)
 
         :param str i_shape_name:
-        :param int i_rep_behavior:
+        :param int i_rep_behavior: enum cat_rep_type
         :param bool i_context:
-        :return: bool
         :rtype: bool
         """
         return self.product.HasShapeRepresentation(i_shape_name, i_rep_behavior, i_context)
 
     def is_catproduct(self):
         """
-        :return: bool
         :rtype: bool
         """
 
@@ -1365,7 +1319,6 @@ class Product(AnyObject):
 
     def is_catpart(self):
         """
-        :return: bool
         :rtype: bool
         """
 
@@ -1385,7 +1338,6 @@ class Product(AnyObject):
         >>> # e://users//psr//Parts//
         >>> Product.path().suffix
         >>> # .CATProduct
-        :return: Path
         :rtype: Path
         """
 
@@ -1418,7 +1370,6 @@ class Product(AnyObject):
                 |
                 |          Engine.RemoveMasterShapeRepresentation()
 
-        :return: None
         :rtype: None
         """
         return self.product.RemoveMasterShapeRepresentation()
@@ -1464,9 +1415,8 @@ class Product(AnyObject):
                 |         ("PART",catRep3D,TRUE)
 
         :param str i_shape_name:
-        :param int i_rep_behavior:
+        :param int i_rep_behavior: enum cat_rep_type
         :param bool i_context:
-        :return: None
         :rtype: None
         """
         return self.product.RemoveShapeRepresentation(i_shape_name, i_rep_behavior, i_context)
@@ -1507,7 +1457,6 @@ class Product(AnyObject):
                 |          Set Rootproduct = productDoc.Product
                 |          Rootproduct.Update
 
-        :return: None
         :rtype: None
         """
         return self.product.Update()
