@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -58,7 +58,6 @@ class Publication(AnyObject):
                 | 
                 |              Pub1.Relay(Pub2)
 
-        :return: Publication
         :rtype: Publication
         """
 
@@ -95,7 +94,6 @@ class Publication(AnyObject):
                 |              Dim Ref As Reference
                 |              Ref = Pub1.Valuation
 
-        :return: AnyObject
         :rtype: AnyObject
         """
 
