@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -62,13 +62,11 @@ class Conflicts(Collection):
                 |              This example retrieves in ThisConflict the ninth
                 |              Conflict
                 |             from the TheConflicts collection. 
-                |             
-                | 
+                |
                 |             Dim ThisConflict As Conflict
                 |             Set ThisConflict = TheConflicts.Item(9)
 
         :param cat_variant i_index:
-        :return: Conflict
         :rtype: Conflict
         """
         return Conflict(self.conflicts.Item(i_index))
@@ -77,11 +75,11 @@ class Conflicts(Collection):
         if (n + 1) > self.count:
             raise StopIteration
 
-        return Conflict(self.conflicts.item(n + 1))
+        return Conflict(self.conflicts.Item(n + 1))
 
     def __iter__(self) -> Iterator[Conflict]:
         for i in range(self.count):
-            yield self.child_object(self.com_object.item(i + 1))
+            yield self.child_object(self.com_object.Item(i + 1))
 
     def __repr__(self):
         return f'Conflicts(name="{self.name}")'
