@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
 
@@ -58,22 +58,15 @@ class Distance(AnyObject):
                 | 
                 |              The first example retrieves the accuracy value of NewDistance
                 |              Distance.
-                |             
-                | 
+                |
                 |             Dim AccuracyValue As double
                 |             AccuracyValue = NewDistance.Accuracy
-                |             
-                | 
-                | 
-                |             
-                | 
+                |
                 |                 The second example sets the accuracy value of NewDistance
                 |                 Distance.
-                |                 
-                | 
+                |
                 |                 NewDistance.Accuracy = 10.
 
-        :return: float
         :rtype: float
         """
 
@@ -102,12 +95,10 @@ class Distance(AnyObject):
                 | 
                 |              This example retrieves the AnnotatedViews collection of
                 |              NewDistance Distance.
-                |             
-                | 
+                |
                 |             Dim TheAnnotatedViewsList As AnnotatedViews
                 |             Set TheAnnotatedViewsList = NewDistance.AnnotatedViews
 
-        :return: AnnotatedViews
         :rtype: AnnotatedViews
         """
 
@@ -128,22 +119,15 @@ class Distance(AnyObject):
                 | 
                 |              The first example retrieves the computation type of NewDistance
                 |              Distance.
-                |             
-                | 
+                |
                 |             Dim ComputationType As CatDistanceComputationType
                 |             ComputationType = NewDistance.ComputationType
-                |             
-                | 
-                | 
-                |             
-                | 
+                |
                 |                 The second example sets the computation type of NewDistance
                 |                 Distance.
-                |                 
-                | 
+                |
                 |                 NewDistance.ComputationType = CatDistanceComputationTypeInsideOne
 
-        :return: int
         :rtype: int
         """
 
@@ -172,23 +156,16 @@ class Distance(AnyObject):
                 | 
                 |              The first example retrieves the first group of NewDistance
                 |              Distance.
-                |             
-                | 
+                |
                 |             Dim FirstGroup As Group
                 |             Set FirstGroup = NewDistance.FirstGroup
-                |             
-                | 
-                | 
-                |             
-                | 
+                |
                 |                 The second example sets the first  group of NewDistance
                 |                 Distance.
-                |                 
-                | 
+                |
                 |                 Dim FirstGroup As Group
                 |                 NewDistance.FirstGroup = FirstGroup
 
-        :return: Group
         :rtype: Group
         """
 
@@ -218,12 +195,10 @@ class Distance(AnyObject):
                 | 
                 |              This example retrieves the first product involved in the
                 |              NewDistance Distance.
-                |             
-                | 
+                |
                 |             Dim AProduct As Product
                 |             Set AProduct = NewDistance.FirstProduct
 
-        :return: Product
         :rtype: Product
         """
 
@@ -249,11 +224,9 @@ class Distance(AnyObject):
                 | 
                 |              This example retrieves the diagnosis on NewDistance
                 |              Distance.
-                |             
-                | 
+                |
                 |             If NewDistance.IsDefined = 1 Then
 
-        :return: int
         :rtype: int
         """
 
@@ -274,12 +247,10 @@ class Distance(AnyObject):
                 | 
                 |              This example retrieves the Marker3Ds collection of NewDistance
                 |              Distance.
-                |             
-                | 
+                |
                 |             Dim TheMarker3DsList As Marker3Ds
                 |             Set TheMarker3DsList = NewDistance.Marker3Ds
 
-        :return: Marker3Ds
         :rtype: Marker3Ds
         """
 
@@ -303,22 +274,15 @@ class Distance(AnyObject):
                 | 
                 |              The first example retrieves the maximum distance value of
                 |              NewDistance Distance.
-                |             
-                | 
+                |
                 |             Dim MaximumValue As double
                 |             MaximumValue = NewDistance.MaximumDistance
-                |             
-                | 
-                | 
-                |             
-                | 
+                |
                 |                 The second example sets the maximum distance value of
                 |                 NewDistance Distance.
-                |                 
-                | 
+                |
                 |                 NewDistance.MaximumDistance = 10.
 
-        :return: float
         :rtype: float
         """
 
@@ -346,24 +310,18 @@ class Distance(AnyObject):
                 | 
                 |     Example:
                 | 
-                |              The first example retrieves the type of NewDistance
-                |              Distance.
-                |             
-                | 
+                |             The first example retrieves the type of NewDistance
+                |             Distance.
+                |
                 |             Dim MeasureType As CatDistanceMeasureType
                 |             MeasureType = NewDistance.MeasureType
-                |             
-                | 
-                | 
-                |             
-                | 
-                |                 The second example sets the Type of NewDistance
-                |                 Distance.
-                |                 
-                | 
-                |                 NewDistance.MeasureType = CatDistanceMeasureTypeMinimum
+                |
+                |             The second example sets the Type of NewDistance
+                |             Distance.
+                |
+                |             NewDistance.MeasureType = CatDistanceMeasureTypeMinimum
 
-        :return: int
+        :return: enum cat_distance_measure_type
         :rtype: int
         """
 
@@ -372,7 +330,7 @@ class Distance(AnyObject):
     @measure_type.setter
     def measure_type(self, value: int):
         """
-        :param int value:
+        :param int value: enum cat_distance_measure_type
         """
 
         self.distance.MeasureType = value
@@ -395,22 +353,15 @@ class Distance(AnyObject):
                 | 
                 |              The first example retrieves the minimum distance value of
                 |              NewDistance Distance.
-                |             
-                | 
+                |
                 |             Dim MinimumValue As double
                 |             MinimumValue = NewDistance.MinimumDistance
-                |             
-                | 
-                | 
-                |             
-                | 
+                |
                 |                 The second example sets the minimum distance value of
                 |                 NewDistance Distance.
-                |                 
-                | 
+                |
                 |                 NewDistance.MinimumDistance = 10.
 
-        :return: float
         :rtype: float
         """
 
@@ -439,23 +390,16 @@ class Distance(AnyObject):
                 | 
                 |              The first example retrieves the second group of NewDistance
                 |              Distance.
-                |             
-                | 
+                |
                 |             Dim SecondGroup As Group
                 |             Set SecondGroup = NewDistance.SecondGroup
-                |             
-                | 
-                | 
-                |             
-                | 
+                |
                 |                 The second example sets the second group of NewDistance
                 |                 Distance.
-                |                 
-                | 
+                |
                 |                 Dim SecondGroup As Group
                 |                 NewDistance.SecondGroup = SecondGroup
 
-        :return: Group
         :rtype: Group
         """
 
@@ -485,12 +429,10 @@ class Distance(AnyObject):
                 | 
                 |              This example retrieves the coordinates in the NewDistance
                 |              Distance.
-                |             
-                | 
+                |
                 |             Dim AProduct As Product
                 |             Set AProduct = NewDistance.SecondProduct
 
-        :return: Product
         :rtype: Product
         """
 
@@ -511,12 +453,10 @@ class Distance(AnyObject):
                 | 
                 |              This example retrieves the value of NewDistance
                 |              Distance.
-                |             
-                | 
+                |
                 |             Dim MinimumValue As double
                 |             MinimumValue = NewDistance.Value
 
-        :return: float
         :rtype: float
         """
 
@@ -536,11 +476,9 @@ class Distance(AnyObject):
                 | 
                 |              This example computes the distance of NewDistance
                 |              Distance.
-                |             
-                | 
+                |
                 |             NewDistance.Compute
 
-        :return: None
         :rtype: None
         """
         return self.distance.Compute()
@@ -570,12 +508,10 @@ class Distance(AnyObject):
                 | 
                 |              This example retrieves the coordinates of the first point in
                 |              NewDistance Distance.
-                |             
-                | 
+                |
                 |             Dim Coordinates (2)
                 |             NewDistance.GetFirstPointCoordinates Coordinates
 
-        :return: tuple
         :rtype: tuple
         """
 
@@ -616,12 +552,10 @@ class Distance(AnyObject):
                 | 
                 |              This example retrieves the coordinates of the first point in
                 |              NewDistance Distance.
-                |             
-                | 
+                |
                 |             Dim Coordinates (2)
                 |             NewDistance.GetSecondPointCoordinates Coordinates
 
-        :return: None
         :rtype: None
         """
 
