@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384
 
@@ -20,6 +20,7 @@ from pycatia.system_interfaces.system_service import SystemService
 if TYPE_CHECKING:
     from pycatia.in_interfaces.document import Document
 
+
 class Section(AnyObject):
     """
         .. note::
@@ -59,12 +60,10 @@ class Section(AnyObject):
                 | 
                 |              This example retrieves the AnnotatedViews collection of NewSection
                 |              Section.
-                |             
-                | 
+                |
                 |             Dim TheAnnotatedViewsList As AnnotatedViews
                 |             Set TheAnnotatedViewsList = NewSection.AnnotatedViews
 
-        :return: AnnotatedViews
         :rtype: AnnotatedViews
         """
 
@@ -88,22 +87,16 @@ class Section(AnyObject):
                 | 
                 |              The first example retrieves the behavior of NewSection
                 |              Section.
-                |             
-                | 
+                |
                 |             Dim SectionBehavior As CatSectionBehavior
                 |             Behavior = NewSection.Behavior
-                |             
-                | 
-                | 
-                |             
-                | 
+                |
                 |                 The second example sets the behavior of NewSection
                 |                 Section.
-                |                 
-                | 
+                |
                 |                 NewSection.Behavior = catSectionBehaviorAutomatic
 
-        :return: int
+        :return: enum cat_section_behavior
         :rtype: int
         """
 
@@ -112,7 +105,7 @@ class Section(AnyObject):
     @behavior.setter
     def behavior(self, value: int):
         """
-        :param int value:
+        :param int value: enum cat_section_behavior
         """
 
         self.section.Behavior = value
@@ -135,22 +128,15 @@ class Section(AnyObject):
                 | 
                 |              The first example retrieves the cutting mode of NewSection
                 |              Section.
-                |             
-                | 
+                |
                 |             Dim SectionMode As Integer
                 |             SectionMode = NewSection.CutMode
-                |             
-                | 
-                | 
-                |             
-                | 
+                |
                 |                 The second example sets the cutting mode of NewSection
                 |                 Section.
-                |                 
-                | 
+                |
                 |                 NewSection.CutMode = 1
 
-        :return: int
         :rtype: int
         """
 
@@ -191,7 +177,6 @@ class Section(AnyObject):
                 |                 Dim AGroup As Group
                 |                 NewSection.Group = AGroup
 
-        :return: Group
         :rtype: Group
         """
 
@@ -222,22 +207,15 @@ class Section(AnyObject):
                 | 
                 |              The first example retrieves the height of NewSection
                 |              Section.
-                |             
-                | 
+                |
                 |             Dim SectionHeight As double
                 |             SectionHeight = NewSection.Height
-                |             
-                | 
-                | 
-                |             
-                | 
+                |
                 |                 The second example sets the height value of NewSection
                 |                 Section.
-                |                 
-                | 
+                |
                 |                 NewSection.Height = 100.
 
-        :return: float
         :rtype: float
         """
 
@@ -266,12 +244,10 @@ class Section(AnyObject):
                 | 
                 |              This example retrieves the Marker3Ds collection of NewSection
                 |              Section.
-                |             
-                | 
+                |
                 |             Dim TheMarker3DsList As Marker3Ds
                 |             Set TheMarker3DsList = NewSection.Marker3Ds
 
-        :return: Marker3Ds
         :rtype: Marker3Ds
         """
 
@@ -294,22 +270,15 @@ class Section(AnyObject):
                 | 
                 |              The first example retrieves the thickness of NewSection
                 |              Section.
-                |             
-                | 
+                |
                 |             Dim SectionThickness As double
                 |             SectionThickness = NewSection.Thickness
-                |             
-                | 
-                | 
-                |             
-                | 
+                |
                 |                 The second example sets the thickness value of NewSection
                 |                 Section.
-                |                 
-                | 
+                |
                 |                 NewSection.Thickness = 100.
 
-        :return: float
         :rtype: float
         """
 
@@ -340,22 +309,16 @@ class Section(AnyObject):
                 | 
                 |              The first example retrieves the type of NewSection
                 |              Section.
-                |             
-                | 
+                |
                 |             Dim SectionType As CatSectionType
                 |             SectionType = NewSection.Type
-                |             
-                | 
-                | 
-                |             
-                | 
+                |
                 |                 The second example sets the type of NewSection
                 |                 Section.
-                |                 
-                | 
+                |
                 |                 NewSection.Type = catSectionTypeSlice
 
-        :return: int
+        :return: enum cat_section_type
         :rtype: int
         """
 
@@ -364,7 +327,7 @@ class Section(AnyObject):
     @type.setter
     def type(self, value: int):
         """
-        :param int value:
+        :param int value: enum cat_section_type
         """
 
         self.section.Type = value
@@ -386,22 +349,15 @@ class Section(AnyObject):
                 | 
                 |              The first example retrieves the width of NewSection
                 |              Section.
-                |             
-                | 
+                |
                 |             Dim SectionWidth As double
                 |             SectionWidth = NewSection.Width
-                |             
-                | 
-                | 
-                |             
-                | 
+                |
                 |                 The second example sets the width value of NewSection
                 |                 Section.
-                |                 
-                | 
+                |
                 |                 NewSection.Width = 100.
 
-        :return: float
         :rtype: float
         """
 
@@ -431,12 +387,10 @@ class Section(AnyObject):
                 | 
                 |              This example exports the section curves of NewSection Section in
                 |              PartDoc document.
-                |             
-                | 
+                |
                 |             Dim PartDoc As Document
                 |             PartDoc = NewSection.Export
 
-        :return: Document
         :rtype: Document
         """
         from pycatia.in_interfaces.document import Document
@@ -491,12 +445,10 @@ class Section(AnyObject):
                 | 
                 |              This example retrieves the position of NewSection
                 |              Section.
-                |             
-                | 
+                |
                 |             Dim Components (11)
                 |             NewSection.GetPosition Components
 
-        :return: tuple
         :rtype: tuple
         """
 
@@ -529,12 +481,10 @@ class Section(AnyObject):
                 | 
                 |              This example retrieves the information on NewSection
                 |              Section.
-                |             
-                | 
+                |
                 |             Dim Indicator
                 |             Indicator = NewSection.IsEmpty
 
-        :return: int
         :rtype: int
         """
         return self.section.IsEmpty()
@@ -578,14 +528,12 @@ class Section(AnyObject):
                 |                 iComponents(10) is the Y component of the
                 |                 origin
                 |                 iComponents(11) is the Z component of the origin
-                |                 
-                | 
+                |
                 |     Example:
                 | 
                 |              This example sets the position of NewSection
                 |              Section.
-                |             
-                | 
+                |
                 |             Dim MatrixPos (11) As Double
                 |             MatrixPos( 0) = 1.0
                 |             MatrixPos( 1) = 0.0
