@@ -1,4 +1,4 @@
-#! usr/bin/python3.6
+#! usr/bin/python3.9
 """
     Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-10 10:58:07.270911
 
@@ -69,7 +69,6 @@ class Collection(PyCATIA):
                 |          Dim CurrentApplication As Application
                 |          Set CurrentApplication = MyDocCollecion.Application
 
-        :return: Application
         :rtype: Application
         """
         from pycatia.in_interfaces.application import Application
@@ -93,7 +92,6 @@ class Collection(PyCATIA):
                 |
                 |          ObjectNumber = MyCollection.Count
 
-        :return: int
         :rtype: int
         """
 
@@ -121,7 +119,6 @@ class Collection(PyCATIA):
                 |
                 |          MyObject.Name("Nice and Handy Object Name")
 
-        :return: str
         :rtype: str
         """
 
@@ -151,7 +148,6 @@ class Collection(PyCATIA):
                 |          Dim ParentObject As AnyObject
                 |          Set ParentObject = GivenObject.Parent
 
-        :return: AnyObject
         :rtype: AnyObject
         """
 
@@ -180,7 +176,6 @@ class Collection(PyCATIA):
                 |         The searched object
 
         :param str id_name:
-        :return: AnyObject
         :rtype: AnyObject
         """
 
@@ -229,11 +224,11 @@ class Collection(PyCATIA):
         if (n + 1) > self.count:
             raise StopIteration
 
-        return AnyObject(self.com_object.item(n + 1))
+        return AnyObject(self.com_object.Item(n + 1))
 
     def __iter__(self) -> Iterator[AnyObject]:
         for i in range(self.count):
-            yield self.child_object(self.com_object.item(i + 1))
+            yield self.child_object(self.com_object.Item(i + 1))
 
     def __repr__(self):
         return f'Collection(name="{self.name}")'
